@@ -100,6 +100,9 @@ class TalosConsumer(object):
             self.consumerClient = consumerClient
         else:
             self.consumerClient = self.talosClientFactory.new_consumer_client()
+            self.lockClient = self.talosClientFactory.new_consumer_client()
+            self.renewWorkerClient = self.talosClientFactory.new_consumer_client()
+            self.queryWorkerClient = self.talosClientFactory.new_consumer_client()
         if talosResourceName:
             self.topicTalosResourceName = talosResourceName
         else:
@@ -243,7 +246,7 @@ class TalosConsumer(object):
         maxRetry = self.talosConsumerConfig.get_renew_max_retry() + 1
         while maxRetry > 0:
             try:
-                renewResponse = self.consumerClient.renew(renewRequest)
+                renewResponse = self.renewWorkerClient.renew(renewRequest)
             except Exception as e:
                 logger.error("Worker: " + self.workerId + " renew error: " + str(traceback.format_exc()))
                 continue
@@ -307,7 +310,7 @@ class TalosConsumer(object):
         tryCount = self.talosConsumerConfig.get_self_register_max_retry() + 1
         while tryCount >= 0:
             try:
-                lockWorkerResponse = self.consumerClient.lock_worker(lockWorkerRequest)
+                lockWorkerResponse = self.lockClient.lock_worker(lockWorkerRequest)
             except Exception as e:
                 logger.error("The worker: " + self.workerId + "register self got error: "
                              + str(traceback.format_exc()))
@@ -325,7 +328,7 @@ class TalosConsumer(object):
     def get_worker_info(self):
         queryWorkerRequest = QueryWorkerRequest(self.consumerGroup,
                                                 self.topicTalosResourceName)
-        queryWorkerResponse = self.consumerClient.query_worker(queryWorkerRequest)
+        queryWorkerResponse = self.queryWorkerClient.query_worker(queryWorkerRequest)
 
         # if queryWorkerInfoMap size equals 0,
         # it represents hbase failed error, do not update local map
