@@ -14,7 +14,7 @@ from talos.thrift.message.ttypes import Message
 from atomic import AtomicLong
 import logging
 import time
-
+import traceback
 
 logger = logging.getLogger("TalosProducerDemo")
 successPutNumber = AtomicLong(0)
@@ -34,7 +34,7 @@ class MyMessageCallback(UserMessageCallback):
 			logger.info("success to put message: " + str(message.message))
 
 		logger.info("success to put message: " + str(count) + " so far.")
-		print ("success to put message: " + str(count) + " so far.")
+		print("success to put message: " + str(count) + " so far.")
 
 	# retry when failed
 	def on_error(self, userMessageResult=None):
@@ -43,7 +43,7 @@ class MyMessageCallback(UserMessageCallback):
 				logger.info("failed to put message: " + message + " we will retry to put it.")
 			talosProducer.add_user_message(userMessageResult.get_message_list())
 		except Exception as e:
-			print (e.message)
+			print(str(traceback.format_exc()))
 
 
 class TalosProducerDemo:
@@ -64,10 +64,14 @@ class TalosProducerDemo:
 
 	def start(self):
 		# init producer
-		talosProducer = TalosProducer(producerConfig=self.producerConfig, credential=self.credential, topicName=self.topicName, topicAbnormalCallback=SimpleAbnormalCallback(), userMessageCallback=MyMessageCallback())
+		talosProducer = TalosProducer(producerConfig=self.producerConfig,
+									  credential=self.credential,
+									  topicName=self.topicName,
+									  topicAbnormalCallback=SimpleAbnormalCallback(),
+									  userMessageCallback=MyMessageCallback())
 
-		messageList = []
 		while True:
+			messageList = []
 			i = 0
 			while i < self.toPutMsgNumber:
 				message = Message(message="test message: this message is a text string.")
